RESIST
======
An API wrapper for `revolt`


Goals
=====
- Strongly typed `revolt` API wrapper.
- Good semantics & conventions.
- Explicit.


Notable contributors
====================
- `Andy <https://github.com/an-dyy>`_ Creater & Maintainer.
